Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/__init__.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/__init__.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/__init__.py	(revision 7811)
@@ -1,8 +1,8 @@
 import os
 
-from waeup.sirp.browser.layout import (
-    SIRPPage, SIRPForm, SIRPLayout, SIRPDisplayFormPage, SIRPEditFormPage,
-    SIRPAddFormPage, NullValidator)
-from waeup.sirp.browser.pages import ContactAdminForm
+from waeup.kofa.browser.layout import (
+    KOFAPage, KOFAForm, KOFALayout, KOFADisplayFormPage, KOFAEditFormPage,
+    KOFAAddFormPage, NullValidator)
+from waeup.kofa.browser.pages import ContactAdminForm
 
 IMAGE_PATH = os.path.join(
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/batchprocessing.txt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/batchprocessing.txt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/batchprocessing.txt	(revision 7811)
@@ -21,5 +21,5 @@
 Create a site:
 
-    >>> from waeup.sirp.app import University
+    >>> from waeup.kofa.app import University
     >>> getRootFolder()['app'] = University()
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/breadcrumbs.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/breadcrumbs.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/breadcrumbs.py	(revision 7811)
@@ -23,16 +23,16 @@
 from zope.publisher.browser import TestRequest
 
-from waeup.sirp.interfaces import (
+from waeup.kofa.interfaces import (
     IConfigurationContainer, ISessionConfiguration)
-from waeup.sirp.interfaces import MessageFactory as _
-from waeup.sirp.browser import interfaces
-from waeup.sirp.browser.interfaces import (IBreadcrumb,
+from waeup.kofa.interfaces import MessageFactory as _
+from waeup.kofa.browser import interfaces
+from waeup.kofa.browser.interfaces import (IBreadcrumb,
     IBreadcrumbIgnorable, IBreadcrumbContainer)
-        
+
 class Breadcrumb(grok.Adapter):
     """A most general breadcrumb generator.
     """
     grok.provides(IBreadcrumb)
-    grok.context(interfaces.ISIRPObject)
+    grok.context(interfaces.IKOFAObject)
     grok.name('index')
 
@@ -42,5 +42,5 @@
     parent_viewname = 'index'
     viewname = 'index'
-    
+
     def __init__(self, context):
         """Turn a context into a breadcrumb.
@@ -57,5 +57,5 @@
             return self.context.title
         if hasattr(self.context, 'name'):
-            return self.context.name            
+            return self.context.name
         return None
 
@@ -151,5 +151,5 @@
 class DataCenterBreadcrumb(Breadcrumb):
     """A breadcrumb for data centers.
-    """ 
+    """
     grok.context(interfaces.IDataCenter)
     title = _(u'Data Center')
@@ -160,5 +160,5 @@
     """
     grok.context(interfaces.IFaculty)
-    
+
     @property
     def title(self):
@@ -169,14 +169,14 @@
     """
     grok.context(interfaces.IDepartment)
-    
+
 class CourseBreadcrumb(FacultyBreadcrumb):
     """A breadcrumb for courses.
     """
-    grok.context(interfaces.ICourse)   
-    
+    grok.context(interfaces.ICourse)
+
 class CertificateBreadcrumb(FacultyBreadcrumb):
     """A breadcrumb for certificates.
     """
-    grok.context(interfaces.ICertificate)        
+    grok.context(interfaces.ICertificate)
 
 class CoursesContainerBreadcrumb(Breadcrumb):
@@ -245,5 +245,5 @@
 
     _breadcrumbs = None
-    
+
     def __init__(self, context):
         self.context = context
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/breadcrumbs.txt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/breadcrumbs.txt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/breadcrumbs.txt	(revision 7811)
@@ -11,5 +11,5 @@
 We create a university to check the breadcrumb functionality.
 
-    >>> from waeup.sirp.app import University
+    >>> from waeup.kofa.app import University
     >>> root = getRootFolder()
     >>> root['app'] = University()
@@ -22,8 +22,8 @@
 viewname:
 
-    >>> from waeup.sirp.browser.breadcrumbs import getBreadcrumbList
+    >>> from waeup.kofa.browser.breadcrumbs import getBreadcrumbList
     >>> blist1 = getBreadcrumbList(app, 'index')
     >>> blist1
-    [<waeup.sirp.browser.breadcrumbs.UniversityBreadcrumb object at 0x...>]
+    [<waeup.kofa.browser.breadcrumbs.UniversityBreadcrumb object at 0x...>]
 
 A slightly more extensive list for the datacenter:
@@ -32,7 +32,7 @@
     >>> from pprint import pprint
     >>> pprint(blist2)
-    [<waeup.sirp.browser.breadcrumbs.UniversityBreadcrumb object at 0x...>,
-     <waeup.sirp.browser.breadcrumbs.AdministrationBreadcrumb object at 0x...>,
-     <waeup.sirp.browser.breadcrumbs.DataCenterBreadcrumb object at 0x...>]
+    [<waeup.kofa.browser.breadcrumbs.UniversityBreadcrumb object at 0x...>,
+     <waeup.kofa.browser.breadcrumbs.AdministrationBreadcrumb object at 0x...>,
+     <waeup.kofa.browser.breadcrumbs.DataCenterBreadcrumb object at 0x...>]
 
 We get a breadcrumb for university, administration area and data
@@ -47,7 +47,7 @@
 
      >>> pprint([(x.context, x.viewname) for x in blist2])
-     [(<waeup.sirp.app.University object at 0x...>, 'index'),
-      (<waeup.sirp.app.University object at 0x...>, 'administration'),
-      (<waeup.sirp.datacenter.DataCenter object at 0x...>, 'index')]
+     [(<waeup.kofa.app.University object at 0x...>, 'index'),
+      (<waeup.kofa.app.University object at 0x...>, 'administration'),
+      (<waeup.kofa.datacenter.DataCenter object at 0x...>, 'index')]
 
 The administration area breadcrumb might be a surprise, as there is no
@@ -89,5 +89,5 @@
 Now we can get the breadcrumbs for this view:
 
-    >>> from waeup.sirp.browser.breadcrumbs import getBreadcrumbListForView
+    >>> from waeup.kofa.browser.breadcrumbs import getBreadcrumbListForView
     >>> blist3 = getBreadcrumbListForView(page)
     >>> [x.title for x in blist3]
@@ -109,5 +109,5 @@
 The returned breadcrumb container supports iteration:
 
-    >>> from waeup.sirp.browser.interfaces import IBreadcrumbContainer
+    >>> from waeup.kofa.browser.interfaces import IBreadcrumbContainer
     >>> mybccontainer = IBreadcrumbContainer(page)
     >>> [x.title for x in mybccontainer]
@@ -131,8 +131,8 @@
 
     >>> from zope.component import getAdapter
-    >>> from waeup.sirp.browser.interfaces import IBreadcrumb
+    >>> from waeup.kofa.browser.interfaces import IBreadcrumb
     >>> b1 = getAdapter(app, IBreadcrumb, 'index')
     >>> b1
-    <waeup.sirp.browser.breadcrumbs.UniversityBreadcrumb object at 0x...>
+    <waeup.kofa.browser.breadcrumbs.UniversityBreadcrumb object at 0x...>
 
 Breadcrumb objects provide a title:
@@ -156,5 +156,5 @@
     >>> b2 = getAdapter(app['datacenter'], IBreadcrumb, 'index')
     >>> b2
-    <waeup.sirp.browser.breadcrumbs.DataCenterBreadcrumb object at 0x...>
+    <waeup.kofa.browser.breadcrumbs.DataCenterBreadcrumb object at 0x...>
 
     >>> b2.title
@@ -168,5 +168,5 @@
 
     >>> b2.parent
-    (<waeup.sirp.app.University object at 0x...>, 'administration')
+    (<waeup.kofa.app.University object at 0x...>, 'administration')
 
 This result denotes a new context object (the University instance we
@@ -184,5 +184,5 @@
     >>> b3 = getAdapter(context, IBreadcrumb, viewname)
     >>> b3
-    <waeup.sirp...breadcrumbs.AdministrationBreadcrumb object at 0x...>
+    <waeup.kofa...breadcrumbs.AdministrationBreadcrumb object at 0x...>
 
 As you can see, we get an AdministrationBreadcrumb, although the
@@ -197,5 +197,5 @@
     >>> context, viewname = b3.parent
     >>> context, viewname
-    (<waeup.sirp.app.University object at 0x...>, 'index')
+    (<waeup.kofa.app.University object at 0x...>, 'index')
 
 We create last breadcrumb:
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/browser.txt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/browser.txt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/browser.txt	(revision 7811)
@@ -1,6 +1,6 @@
-Browsing SIRP
+Browsing KOFA
 *************
 
-Here we visit all parts of a SIRP portal using a browser.
+Here we visit all parts of a KOFA portal using a browser.
 
 University
@@ -15,5 +15,5 @@
   []
 
-  >>> from waeup.sirp.app import University
+  >>> from waeup.kofa.app import University
   >>> u = University()
   >>> root['myuniversity'] = u
@@ -35,5 +35,5 @@
   >>> print browser.contents
   <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"...
-  ...Welcome to WAeUP.SIRP...
+  ...Welcome to WAeUP.KOFA...
   ...
 
@@ -566,5 +566,5 @@
 Courses are stored in :class:`ICoursesContainer` instances with their
 code as key. CoursesContainers are normally availabe as `course`
-attribute of :class:`waeup.sirp.university.department.Department`
+attribute of :class:`waeup.kofa.university.department.Department`
 instances.
 
@@ -769,5 +769,5 @@
 with their code as key. CertificatesContainers are normally availabe as
 `certificates` attribute of
-:class:`waeup.sirp.university.department.Department` instances.
+:class:`waeup.kofa.university.department.Department` instances.
 
 To ease the life of users we do not require to browse the
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/captcha.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/captcha.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/captcha.py	(revision 7811)
@@ -28,9 +28,9 @@
 from zope.interface import Interface
 from zope.publisher.interfaces.http import IHTTPRequest
-from waeup.sirp.browser import SIRPPage
-from waeup.sirp.browser.interfaces import (
+from waeup.kofa.browser import KOFAPage
+from waeup.kofa.browser.interfaces import (
     ICaptchaRequest, ICaptchaResponse, ICaptcha, ICaptchaConfig,
     ICaptchaManager)
-from waeup.sirp.interfaces import IUniversity
+from waeup.kofa.interfaces import IUniversity
 
 #
@@ -171,5 +171,5 @@
     """ReCaptcha - strong captchas with images, sound, etc.
 
-    This is the SIRP implementation to support captchas as provided by
+    This is the KOFA implementation to support captchas as provided by
     http://www.google.com/recaptcha.
 
@@ -266,5 +266,5 @@
             headers = {
                 "Content-type": "application/x-www-form-urlencoded",
-                "User-agent": "reCAPTCHA Python SIRP",
+                "User-agent": "reCAPTCHA Python KOFA",
                 }
             )
@@ -319,5 +319,5 @@
 
 
-class CaptchaTestPage(SIRPPage):
+class CaptchaTestPage(KOFAPage):
     # A test page to see a captcha in action
     grok.name('captcha')
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/exceptions.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/exceptions.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/exceptions.py	(revision 7811)
@@ -22,5 +22,5 @@
 from zope.publisher.interfaces import INotFound
 from zope.security.interfaces import IUnauthorized
-from waeup.sirp.browser.layout import SIRPPage
+from waeup.kofa.browser.layout import KOFAPage
 
 grok.templatedir('templates')
@@ -61,5 +61,5 @@
 
 
-class NotFoundPage(SIRPPage):
+class NotFoundPage(KOFAPage):
     """A page rendered when an object cannot be found.
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/interfaces.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/interfaces.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/interfaces.py	(revision 7811)
@@ -20,7 +20,7 @@
 from zope import schema
 from zope.interface import Interface, Attribute
-from waeup.sirp.interfaces import (
-    ISIRPObject, IUniversity, IUsersContainer, IDataCenter)
-from waeup.sirp.university.interfaces import (
+from waeup.kofa.interfaces import (
+    IKOFAObject, IUniversity, IUsersContainer, IDataCenter)
+from waeup.kofa.university.interfaces import (
     IFacultiesContainer, IFaculty, IFacultyAdd, IDepartment, IDepartmentAdd,
     ICoursesContainer, ICourse, ICourseAdd, ICertificatesContainer,
@@ -63,5 +63,5 @@
     Themes are basically collections of CSS- and/or JavaScript files
     stored somewhere. In Grok-contexts these files can be registered
-    as 'resources' (see :mod:`waeup.sirp.browser.resources`).
+    as 'resources' (see :mod:`waeup.kofa.browser.resources`).
 
     Furthermore, to make themes selectable and distinctable from each
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/pages.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/pages.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/pages.py	(revision 7811)
@@ -16,5 +16,5 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-""" Viewing components for SIRP objects.
+""" Viewing components for KOFA objects.
 """
 import copy
@@ -37,30 +37,30 @@
 from zope.event import notify
 from zope.session.interfaces import ISession
-from waeup.sirp.browser import (
-    SIRPPage, SIRPForm, SIRPEditFormPage, SIRPAddFormPage,
-    SIRPDisplayFormPage, NullValidator)
-from waeup.sirp.browser.interfaces import (
+from waeup.kofa.browser import (
+    KOFAPage, KOFAForm, KOFAEditFormPage, KOFAAddFormPage,
+    KOFADisplayFormPage, NullValidator)
+from waeup.kofa.browser.interfaces import (
     IUniversity, IFacultiesContainer, IFaculty, IFacultyAdd,
     IDepartment, IDepartmentAdd, ICourse, ICourseAdd, ICertificate,
     ICertificateAdd, ICertificateCourse, ICertificateCourseAdd)
-from waeup.sirp.interfaces import MessageFactory as _
-from waeup.sirp.browser.resources import warning, datepicker, tabs, datatable
-from waeup.sirp.interfaces import(
-    ISIRPObject, IUsersContainer, IUserAccount, IDataCenter,
-    ISIRPXMLImporter, ISIRPXMLExporter, IBatchProcessor,
+from waeup.kofa.interfaces import MessageFactory as _
+from waeup.kofa.browser.resources import warning, datepicker, tabs, datatable
+from waeup.kofa.interfaces import(
+    IKOFAObject, IUsersContainer, IUserAccount, IDataCenter,
+    IKOFAXMLImporter, IKOFAXMLExporter, IBatchProcessor,
     ILocalRolesAssignable, DuplicationError, IConfigurationContainer,
     ISessionConfiguration, ISessionConfigurationAdd,
-    IPasswordValidator, IContactForm, ISIRPUtils)
-from waeup.sirp.permissions import get_users_with_local_roles, get_all_roles
-from waeup.sirp.students.catalog import search as searchstudents
-from waeup.sirp.university.catalog import search
-from waeup.sirp.university.vocabularies import course_levels
-from waeup.sirp.authentication import LocalRoleSetEvent
-from waeup.sirp.widgets.restwidget import ReSTDisplayWidget
-from waeup.sirp.authentication import get_principal_role_manager
-from waeup.sirp.utils.helpers import get_user_account
-from waeup.sirp.browser.layout import jsaction, action, UtilityView
-
-grok.context(ISIRPObject)
+    IPasswordValidator, IContactForm, IKOFAUtils)
+from waeup.kofa.permissions import get_users_with_local_roles, get_all_roles
+from waeup.kofa.students.catalog import search as searchstudents
+from waeup.kofa.university.catalog import search
+from waeup.kofa.university.vocabularies import course_levels
+from waeup.kofa.authentication import LocalRoleSetEvent
+from waeup.kofa.widgets.restwidget import ReSTDisplayWidget
+from waeup.kofa.authentication import get_principal_role_manager
+from waeup.kofa.utils.helpers import get_user_account
+from waeup.kofa.browser.layout import jsaction, action, UtilityView
+
+grok.context(IKOFAObject)
 grok.templatedir('templates')
 
@@ -144,9 +144,9 @@
 #
 
-class LoginPage(SIRPPage):
+class LoginPage(KOFAPage):
     """A login page, available for all objects.
     """
     grok.name('login')
-    grok.context(ISIRPObject)
+    grok.context(IKOFAObject)
     grok.require('waeup.Public')
     label = _(u'Login')
@@ -179,8 +179,8 @@
 
 
-class LogoutPage(SIRPPage):
+class LogoutPage(KOFAPage):
     """A logout page. Calling this page will log the current user out.
     """
-    grok.context(ISIRPObject)
+    grok.context(IKOFAObject)
     grok.require('waeup.Public')
     grok.name('logout')
@@ -190,17 +190,17 @@
             auth = getUtility(IAuthentication)
             ILogout(auth).logout(self.request)
-            self.flash(_("You have been logged out. Thanks for using WAeUP SIRP!"))
+            self.flash(_("You have been logged out. Thanks for using WAeUP KOFA!"))
         self.redirect(self.application_url())
 
 
-class LanguageChangePage(SIRPPage):
+class LanguageChangePage(KOFAPage):
     """ Language switch
     """
-    grok.context(ISIRPObject)
+    grok.context(IKOFAObject)
     grok.name('change_language')
     grok.require('waeup.Public')
 
     def update(self, lang='en', view_name='@@index'):
-        self.response.setCookie('sirp.language', lang, path='/')
+        self.response.setCookie('kofa.language', lang, path='/')
         self.redirect(self.url(self.context, view_name))
         return
@@ -213,5 +213,5 @@
 #
 
-class ContactAdminForm(SIRPForm):
+class ContactAdminForm(KOFAForm):
     grok.name('contactadmin')
     #grok.context(IUniversity)
@@ -242,6 +242,6 @@
         usertype = getattr(self.request.principal,
                            'user_type', 'system').title()
-        sirp_utils = getUtility(ISIRPUtils)
-        success = sirp_utils.sendContactForm(
+        kofa_utils = getUtility(IKOFAUtils)
+        success = kofa_utils.sendContactForm(
                 fullname,email,
                 self.config.name_admin,self.config.email_admin,
@@ -263,6 +263,6 @@
     @action(_('Send now'), style='primary')
     def send(self, *args, **data):
-        sirp_utils = getUtility(ISIRPUtils)
-        success = sirp_utils.sendContactForm(
+        kofa_utils = getUtility(IKOFAUtils)
+        success = kofa_utils.sendContactForm(
                 data['fullname'],data['email_from'],
                 self.config.name_admin,self.config.email_admin,
@@ -279,5 +279,5 @@
 #
 
-class UniversityPage(SIRPDisplayFormPage):
+class UniversityPage(KOFADisplayFormPage):
     """ The main university page.
     """
@@ -290,6 +290,6 @@
     @property
     def frontpage(self):
-        portal_language = getUtility(ISIRPUtils).PORTAL_LANGUAGE
-        lang = self.request.cookies.get('sirp.language', portal_language)
+        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        lang = self.request.cookies.get('kofa.language', portal_language)
         html = self.context['configuration'].frontpage_dict.get(lang,'')
         if html =='':
@@ -297,9 +297,9 @@
                 'configuration'].frontpage_dict.get(portal_language,'')
         if html =='':
-            return _(u'<h1>Welcome to WAeUP.SIRP</h1>')
+            return _(u'<h1>Welcome to WAeUP.KOFA</h1>')
         else:
             return html
 
-class AdministrationPage(SIRPPage):
+class AdministrationPage(KOFAPage):
     """ The administration overview page.
     """
@@ -319,5 +319,5 @@
 
     name = 'General news feed'
-    description = 'waeup.sirp now supports RSS 2.0 feeds :-)'
+    description = 'waeup.kofa now supports RSS 2.0 feeds :-)'
     language = None
     date = None
@@ -378,5 +378,5 @@
 #
 
-class UsersContainerPage(SIRPPage):
+class UsersContainerPage(KOFAPage):
     """Overview page for all local users.
     """
@@ -418,5 +418,5 @@
         return site_roles_string
 
-class AddUserFormPage(SIRPAddFormPage):
+class AddUserFormPage(KOFAAddFormPage):
     grok.require('waeup.manageUsers')
     grok.context(IUsersContainer)
@@ -456,5 +456,5 @@
         self.redirect(self.url(self.context))
 
-class UserManageFormPage(SIRPEditFormPage):
+class UserManageFormPage(KOFAEditFormPage):
     """Manage a user account.
     """
@@ -525,6 +525,6 @@
         usertype = getattr(self.request.principal,
                            'user_type', 'system').title()
-        sirp_utils = getUtility(ISIRPUtils)
-        success = sirp_utils.sendContactForm(
+        kofa_utils = getUtility(IKOFAUtils)
+        success = kofa_utils.sendContactForm(
                 self.request.principal.title,email,
                 self.context.title,self.context.email,
@@ -550,5 +550,5 @@
         self.widgets['title'].displayWidth = 30
 
-class MyRolesPage(SIRPPage):
+class MyRolesPage(KOFAPage):
     """Display site roles and local roles assigned to officers.
     """
@@ -581,5 +581,5 @@
 #
 
-class SearchPage(SIRPPage):
+class SearchPage(KOFAPage):
     """General search page for the academics section.
     """
@@ -608,5 +608,5 @@
 #
 
-class ConfigurationContainerDisplayFormPage(SIRPDisplayFormPage):
+class ConfigurationContainerDisplayFormPage(KOFADisplayFormPage):
     """View page of the configuration container.
     """
@@ -619,5 +619,5 @@
     form_fields['frontpage'].custom_widget = ReSTDisplayWidget
 
-class ConfigurationContainerManageFormPage(SIRPEditFormPage):
+class ConfigurationContainerManageFormPage(KOFAEditFormPage):
     """Manage page of the configuration container. We always use the
     manage page in the UI not the view page, thus we use the index name here.
@@ -684,5 +684,5 @@
         return
 
-class SessionConfigurationAddFormPage(SIRPAddFormPage):
+class SessionConfigurationAddFormPage(KOFAAddFormPage):
     """Add a session configuration object to configuration container.
     """
@@ -711,5 +711,5 @@
         return
 
-class SessionConfigurationManageFormPage(SIRPEditFormPage):
+class SessionConfigurationManageFormPage(KOFAEditFormPage):
     """Manage session configuration object.
     """
@@ -742,5 +742,5 @@
 #
 
-class DatacenterPage(SIRPPage):
+class DatacenterPage(KOFAPage):
     grok.context(IDataCenter)
     grok.name('index')
@@ -749,5 +749,5 @@
     pnav = 0
 
-class DatacenterUploadPage(SIRPPage):
+class DatacenterUploadPage(KOFAPage):
     grok.context(IDataCenter)
     grok.name('upload')
@@ -794,5 +794,5 @@
         return '%s_%s%s' % (base, filtered_username, ext.lower())
 
-class DatacenterImportStep1(SIRPPage):
+class DatacenterImportStep1(KOFAPage):
     """Manual import step 1: choose file
     """
@@ -820,9 +820,9 @@
         if select is not None:
             # A filename was selected
-            session = ISession(self.request)['waeup.sirp']
+            session = ISession(self.request)['waeup.kofa']
             session['import_filename'] = select
             self.redirect(self.url(self.context, '@@import2'))
 
-class DatacenterImportStep2(SIRPPage):
+class DatacenterImportStep2(KOFAPage):
     """Manual import step 2: choose importer
     """
@@ -909,5 +909,5 @@
     def update(self, mode=None, importer=None,
                back1=None, cancel=None, proceed=None):
-        session = ISession(self.request)['waeup.sirp']
+        session = ISession(self.request)['waeup.kofa']
         self.filename = session.get('import_filename', None)
 
@@ -944,5 +944,5 @@
             self.flash(warnings)
 
-class DatacenterImportStep3(SIRPPage):
+class DatacenterImportStep3(KOFAPage):
     """Manual import step 3: modify header
     """
@@ -1023,5 +1023,5 @@
 
     def update(self, headerfield=None, back2=None, cancel=None, proceed=None):
-        session = ISession(self.request)['waeup.sirp']
+        session = ISession(self.request)['waeup.kofa']
         self.filename = session.get('import_filename', None)
         self.mode = session.get('import_mode', None)
@@ -1052,5 +1052,5 @@
             self.flash(warnings)
 
-class DatacenterImportStep4(SIRPPage):
+class DatacenterImportStep4(KOFAPage):
     """Manual import step 4: do actual import
     """
@@ -1074,5 +1074,5 @@
             self.redirect(self.url(self.context))
             return
-        session = ISession(self.request)['waeup.sirp']
+        session = ISession(self.request)['waeup.kofa']
         self.filename = session.get('import_filename', None)
         self.mode = session.get('import_mode', None)
@@ -1111,5 +1111,5 @@
             mapping = {'a':linenum - self.warn_num}))
 
-class DatacenterLogsOverview(SIRPPage):
+class DatacenterLogsOverview(KOFAPage):
     grok.context(IDataCenter)
     grok.name('logs')
@@ -1122,5 +1122,5 @@
 
     def update(self, show=None, logname=None, back=None):
-        session = ISession(self.request)['waeup.sirp']
+        session = ISession(self.request)['waeup.kofa']
         if back is not None:
             self.redirect(self.url(self.context))
@@ -1133,5 +1133,5 @@
         self.files = self.context.getLogFiles()
 
-class DatacenterLogsFileview(SIRPPage):
+class DatacenterLogsFileview(KOFAPage):
     grok.context(IDataCenter)
     grok.name('show')
@@ -1153,5 +1153,5 @@
             self.redirect(self.url(self.context, '@@logs'))
             return
-        session = ISession(self.request)['waeup.sirp']
+        session = ISession(self.request)['waeup.kofa']
         logname = session.get('logname', None)
         if back is not None or logname is None:
@@ -1172,5 +1172,5 @@
         popen.close()
 
-class DatacenterSettings(SIRPPage):
+class DatacenterSettings(KOFAPage):
     grok.context(IDataCenter)
     grok.name('manage')
@@ -1215,5 +1215,5 @@
 
     def render(self):
-        exporter = ISIRPXMLExporter(self.context)
+        exporter = IKOFAXMLExporter(self.context)
         xml = exporter.export().read()
         self.response.setHeader(
@@ -1221,5 +1221,5 @@
         return xml
 
-class ImportXMLPage(SIRPPage):
+class ImportXMLPage(KOFAPage):
     """Replace the context object by an object created from an XML
        representation.
@@ -1237,5 +1237,5 @@
         if not xmlfile:
             return
-        importer = ISIRPXMLImporter(self.context)
+        importer = IKOFAXMLImporter(self.context)
         obj = importer.doImport(xmlfile)
         if type(obj) != type(self.context):
@@ -1257,5 +1257,5 @@
 #
 
-class FacultiesContainerPage(SIRPPage):
+class FacultiesContainerPage(KOFAPage):
     """ Index page for faculty containers.
     """
@@ -1267,5 +1267,5 @@
     grok.template('facultypage')
 
-class FacultiesContainerManageFormPage(SIRPEditFormPage):
+class FacultiesContainerManageFormPage(KOFAEditFormPage):
     """Manage the basic properties of a `Faculty` instance.
     """
@@ -1302,5 +1302,5 @@
 
 
-class FacultyAddFormPage(SIRPAddFormPage):
+class FacultyAddFormPage(KOFAAddFormPage):
     """ Page form to add a new faculty to a faculty container.
     """
@@ -1330,5 +1330,5 @@
 # Faculty pages
 #
-class FacultyPage(SIRPPage):
+class FacultyPage(KOFAPage):
     """Index page of faculties.
     """
@@ -1342,5 +1342,5 @@
         return _('Departments')
 
-class FacultyManageFormPage(SIRPEditFormPage):
+class FacultyManageFormPage(KOFAEditFormPage):
     """Manage the basic properties of a `Faculty` instance.
     """
@@ -1416,5 +1416,5 @@
         return del_local_roles(self,3,**data)
 
-class DepartmentAddFormPage(SIRPAddFormPage):
+class DepartmentAddFormPage(KOFAAddFormPage):
     """Add a department to a faculty.
     """
@@ -1446,5 +1446,5 @@
 # Department pages
 #
-class DepartmentPage(SIRPPage):
+class DepartmentPage(KOFAPage):
     """Department index page.
     """
@@ -1475,5 +1475,5 @@
             yield(dict(url=url, name=key, container=val))
 
-class ShowStudentsInDepartmentPage(SIRPPage):
+class ShowStudentsInDepartmentPage(KOFAPage):
     """Page that lists all students in the department.
     """
@@ -1510,5 +1510,5 @@
         return hitlist
 
-class DepartmentManageFormPage(SIRPEditFormPage):
+class DepartmentManageFormPage(KOFAEditFormPage):
     """Manage the basic properties of a `Department` instance.
     """
@@ -1612,5 +1612,5 @@
         return del_local_roles(self,4,**data)
 
-class CourseAddFormPage(SIRPAddFormPage):
+class CourseAddFormPage(KOFAAddFormPage):
     """Add-form to add course to a department.
     """
@@ -1649,5 +1649,5 @@
         return
 
-class CertificateAddFormPage(SIRPAddFormPage):
+class CertificateAddFormPage(KOFAAddFormPage):
     """Add-form to add certificate to a department.
     """
@@ -1690,5 +1690,5 @@
 # Courses pages
 #
-class CoursePage(SIRPDisplayFormPage):
+class CoursePage(KOFADisplayFormPage):
     """Course index page.
     """
@@ -1703,5 +1703,5 @@
         return '%s (%s)' % (self.context.title, self.context.code)
 
-class CourseManageFormPage(SIRPEditFormPage):
+class CourseManageFormPage(KOFAEditFormPage):
     """Edit form page for courses.
     """
@@ -1734,5 +1734,5 @@
 # Certificate pages
 #
-class CertificatePage(SIRPDisplayFormPage):
+class CertificatePage(KOFADisplayFormPage):
     """Index page for certificates.
     """
@@ -1752,5 +1752,5 @@
         return super(CertificatePage, self).update()
 
-class CertificateManageFormPage(SIRPEditFormPage):
+class CertificateManageFormPage(KOFAEditFormPage):
     """Manage the properties of a `Certificate` instance.
     """
@@ -1830,5 +1830,5 @@
 
 
-class CertificateCourseAddFormPage(SIRPAddFormPage):
+class CertificateCourseAddFormPage(KOFAAddFormPage):
     """Add-page to add a course ref to a certificate
     """
@@ -1862,5 +1862,5 @@
 # Certificate course pages...
 #
-class CertificateCoursePage(SIRPPage):
+class CertificateCoursePage(KOFAPage):
     """CertificateCourse index page.
     """
@@ -1879,5 +1879,5 @@
         return course_levels.getTerm(self.context.level).title
 
-class CertificateCourseManageFormPage(SIRPEditFormPage):
+class CertificateCourseManageFormPage(KOFAEditFormPage):
     """Manage the basic properties of a `CertificateCourse` instance.
     """
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/static/datatable.js
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/static/datatable.js	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/static/datatable.js	(revision 7811)
@@ -4,5 +4,5 @@
 		"aaSorting": [[ 1, "asc" ]],
 		"aoColumnDefs":[{ "bSortable": false, "aTargets": [ 0 ] }]
-	} );    
+	} );
 });
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/static/datepicker.js
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/static/datepicker.js	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/static/datepicker.js	(revision 7811)
@@ -1,4 +1,4 @@
 $(function() {
-  $( ".datepicker" ).datepicker({ dateFormat: 'yy-mm-dd', 
+  $( ".datepicker" ).datepicker({ dateFormat: 'yy-mm-dd',
                                   duration: 'fast'
   });
@@ -24,5 +24,5 @@
 
 $(function() {
-  $( ".datepicker-year" ).datepicker({ dateFormat: 'yy-mm-dd', 
+  $( ".datepicker-year" ).datepicker({ dateFormat: 'yy-mm-dd',
 	duration: 'fast',
 	changeYear: true,
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/static/waeup-base.css
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/static/waeup-base.css	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/static/waeup-base.css	(revision 7811)
@@ -1,3 +1,3 @@
-/* This is the base stylesheet for SIRP. It defines base styles
+/* This is the base stylesheet for KOFA. It defines base styles
 additionally or modifying Bootstrap styles. For themes, please create
 a stylesheet overriding values set here in a file named
@@ -132,5 +132,5 @@
 }
 
- /* SIRP stuff */
+ /* KOFA stuff */
 
 div.actionbar {
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/certificatecoursepage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/certificatecoursepage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/certificatecoursepage.pt	(revision 7811)
@@ -1,3 +1,3 @@
-<table i18n:domain="waeup.sirp" class="form-table">
+<table i18n:domain="waeup.kofa" class="form-table">
   <thead>
   </thead>
@@ -6,9 +6,9 @@
       <td i18n:translate="">Code:</td>
       <td tal:content="context/__name__">CODE</td>
-    </tr>  
+    </tr>
     <tr>
       <td i18n:translate="">Course Code:</td>
       <td tal:content="context/getCourseCode">THE COURSE</td>
-    </tr>    
+    </tr>
     <tr>
       <td i18n:translate="">Course Title:</td>
@@ -17,10 +17,10 @@
     <tr>
       <td i18n:translate="">Provided by:</td>
-      <td> 
+      <td>
       <span tal:content="python: context.course.__parent__.__parent__.longtitle()">DEPARTMENT</span>
       <br />
       <span tal:content="python: context.course.__parent__.__parent__.__parent__.longtitle()">FACULTY</span>
       </td>
-    </tr>    
+    </tr>
     <tr>
       <td i18n:translate="">Level:</td>
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/certificatemanagepage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/certificatemanagepage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/certificatemanagepage.pt	(revision 7811)
@@ -1,4 +1,4 @@
 <form action="." tal:attributes="action request/URL" method="POST"
-      enctype="multipart/form-data" i18n:domain="waeup.sirp">
+      enctype="multipart/form-data" i18n:domain="waeup.kofa">
 
   <ul class="tabs" data-tabs="tabs">
@@ -7,5 +7,5 @@
     <li tal:attributes="class view/tab3"><a href="#tab-3" i18n:translate="">Local Roles</a></li>
   </ul>
-   
+
   <div class="tab-content">
     <div id="tab-1" tal:attributes="class view/tab1">
@@ -136,5 +136,5 @@
     </div>
   </div>
-</form>  
+</form>
 
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/certificatepage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/certificatepage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/certificatepage.pt	(revision 7811)
@@ -1,5 +1,5 @@
 <table class="form-table">
 <thead>
-</thead>  
+</thead>
 <tbody>
   <tal:block repeat="widget view/widgets">
@@ -20,8 +20,8 @@
 <h3>
   <span tal:content="context/__name__">Code</span>
-  <span i18n:domain="waeup.sirp" i18n:translate="">Course Referrers</span>
+  <span i18n:domain="waeup.kofa" i18n:translate="">Course Referrers</span>
 </h3>
 <br />
-<table i18n:domain="waeup.sirp" class="display dataTable">
+<table i18n:domain="waeup.kofa" class="display dataTable">
 <thead>
   <tr>
@@ -49,5 +49,5 @@
 	     tal:content="cc/course/code">
     	COURSE CODE
-      </a>     
+      </a>
     <td>
       <span tal:content="cc/course/title">
@@ -59,5 +59,5 @@
 	   MANDATORY
       </span>
-    </td>                
+    </td>
   </tr>
 </tbody>
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/configurationmanagepage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/configurationmanagepage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/configurationmanagepage.pt	(revision 7811)
@@ -1,4 +1,4 @@
 <form action="." tal:attributes="action request/URL" method="POST"
-  enctype="multipart/form-data" i18n:domain="waeup.sirp">
+  enctype="multipart/form-data" i18n:domain="waeup.kofa">
     <ul class="tabs" data-tabs="tabs">
       <li tal:attributes="class view/tab1">
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/contactform.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/contactform.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/contactform.pt	(revision 7811)
@@ -3,5 +3,5 @@
 
   <tal:block repeat="widget view/widgets">
-    
+
     <div tal:condition="python: widget.name != 'form.body'"
          tal:content="widget/label">Label
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/datacenterimport1page.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/datacenterimport1page.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/datacenterimport1page.pt	(revision 7811)
@@ -1,11 +1,11 @@
-<h3 i18n:domain="waeup.sirp" i18n:translate="">Step 1</h3>
-<p i18n:domain="waeup.sirp" i18n:translate="">
+<h3 i18n:domain="waeup.kofa" i18n:translate="">Step 1</h3>
+<p i18n:domain="waeup.kofa" i18n:translate="">
   Using batch processing you can mass-create, mass-update, or
   mass-remove datasets from the database using CSV files.
 </p>
-<p i18n:domain="waeup.sirp" i18n:translate="">
+<p i18n:domain="waeup.kofa" i18n:translate="">
   Please select a file for processing from the list below.
 </p>
-<form i18n:domain="waeup.sirp" method="POST">
+<form i18n:domain="waeup.kofa" method="POST">
   <table>
     <thead>
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/datacenterimport2page.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/datacenterimport2page.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/datacenterimport2page.pt	(revision 7811)
@@ -1,4 +1,4 @@
-<h3 i18n:domain="waeup.sirp" i18n:translate="">Step 2</h3>
-<form i18n:domain="waeup.sirp" method="POST">
+<h3 i18n:domain="waeup.kofa" i18n:translate="">Step 2</h3>
+<form i18n:domain="waeup.kofa" method="POST">
   <p>
     <b i18n:translate="">File:</b>
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/datacenterimport3page.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/datacenterimport3page.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/datacenterimport3page.pt	(revision 7811)
@@ -1,9 +1,9 @@
-<div i18n:domain="waeup.sirp" i18n:translate=""
+<div i18n:domain="waeup.kofa" i18n:translate=""
   class="alert-message success" tal:condition="not: view/getWarnings">
   Header fields OK
 </div>
 
-<h3 i18n:domain="waeup.sirp" i18n:translate="">Step 3</h3>
-<form i18n:domain="waeup.sirp">
+<h3 i18n:domain="waeup.kofa" i18n:translate="">Step 3</h3>
+<form i18n:domain="waeup.kofa">
   <p i18n:translate="">
     Eventually modify headerfields of import file below.
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/datacenterimport4page.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/datacenterimport4page.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/datacenterimport4page.pt	(revision 7811)
@@ -1,18 +1,18 @@
-<h3 i18n:domain="waeup.sirp" i18n:translate="">Step 4</h3>
-<p i18n:domain="waeup.sirp" i18n:translate="">
+<h3 i18n:domain="waeup.kofa" i18n:translate="">Step 4</h3>
+<p i18n:domain="waeup.kofa" i18n:translate="">
   Batch processing finished.
 </p>
-<p i18n:domain="waeup.sirp">
+<p i18n:domain="waeup.kofa">
   <b i18n:translate="">File:</b> <span tal:content="view/filename">Filename.csv</span>
 </p>
-<p i18n:domain="waeup.sirp">
+<p i18n:domain="waeup.kofa">
   <b i18n:translate="">Processor:</b>
   <span tal:content="view/importer/name">Importer Name</span>
 </p>
-<p i18n:domain="waeup.sirp">
+<p i18n:domain="waeup.kofa">
   <b i18n:translate="">Processing mode: </b>
   <span tal:content="view/mode">mode</span>
 </p>
-<form method="POST" i18n:domain="waeup.sirp">
+<form method="POST" i18n:domain="waeup.kofa">
   <input class="btn primary" type="submit" name="finish"
     tal:attributes="value view/back_button" />
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/datacenterlogspage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/datacenterlogspage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/datacenterlogspage.pt	(revision 7811)
@@ -1,3 +1,3 @@
-<div i18n:domain="waeup.sirp" tal:define="files view/files">
+<div i18n:domain="waeup.kofa" tal:define="files view/files">
   <p i18n:translate="" tal:condition="not: files">
   Currently no log files are available.
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/datacentermanagepage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/datacentermanagepage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/datacentermanagepage.pt	(revision 7811)
@@ -1,3 +1,3 @@
-<form  i18n:domain="waeup.sirp" method="POST">
+<form  i18n:domain="waeup.kofa" method="POST">
   <div>
     <span  i18n:translate="">Storage path:</span>
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/datacenterpage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/datacenterpage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/datacenterpage.pt	(revision 7811)
@@ -1,13 +1,13 @@
-<p  i18n:domain="waeup.sirp" i18n:translate="">
+<p  i18n:domain="waeup.kofa" i18n:translate="">
 The data center helps you to manage portal data. You can upload CSV
 files here, which will be available for import afterwards.
 </p>
 
-<p i18n:domain="waeup.sirp">
+<p i18n:domain="waeup.kofa">
   <b i18n:translate="">Storage path:</b>
   <span tal:content="context/storage">/foo/bar</span>
 </p>
 
-<table i18n:domain="waeup.sirp">
+<table i18n:domain="waeup.kofa">
   <thead>
     <tr>
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/departmentmanagepage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/departmentmanagepage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/departmentmanagepage.pt	(revision 7811)
@@ -1,4 +1,4 @@
 <form action="." tal:attributes="action request/URL" method="POST"
-  i18n:domain="waeup.sirp" enctype="multipart/form-data">
+  i18n:domain="waeup.kofa" enctype="multipart/form-data">
   <ul class="tabs" data-tabs="tabs">
     <li tal:attributes="class view/tab1">
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/departmentpage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/departmentpage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/departmentpage.pt	(revision 7811)
@@ -1,3 +1,3 @@
-<ul i18n:domain="waeup.sirp" class="tabs" data-tabs="tabs">
+<ul i18n:domain="waeup.kofa" class="tabs" data-tabs="tabs">
   <li class="active"><a href="#tab-1">
    <span i18n:translate="">Courses</span></a>
@@ -7,7 +7,7 @@
   </li>
 </ul>
-<div  i18n:domain="waeup.sirp" class="tab-content">
+<div  i18n:domain="waeup.kofa" class="tab-content">
     <div id="tab-1" class="active">
-    <br /> 
+    <br />
     <table class="display dataTable">
       <thead>
@@ -26,10 +26,10 @@
           <td tal:content="entry/container/title">
     	       Title
-          </td> 
+          </td>
         </tr>
       </tbody>
     </table>
     <br /><br />
-    </div> 
+    </div>
     <div id="tab-2">
     <br />
@@ -50,5 +50,5 @@
           <td tal:content="entry/container/title">
     	       Title
-          </td> 
+          </td>
         </tr>
       </tbody>
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/facultymanagepage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/facultymanagepage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/facultymanagepage.pt	(revision 7811)
@@ -1,4 +1,4 @@
 <form action="." tal:attributes="action request/URL"
-  i18n:domain="waeup.sirp" method="POST" enctype="multipart/form-data">
+  i18n:domain="waeup.kofa" method="POST" enctype="multipart/form-data">
   <ul class="tabs" data-tabs="tabs">
     <li tal:attributes="class view/tab1">
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/facultypage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/facultypage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/facultypage.pt	(revision 7811)
@@ -1,7 +1,7 @@
-<div i18n:domain="waeup.sirp" i18n:translate="" tal:condition="python: not len(context.keys())">
+<div i18n:domain="waeup.kofa" i18n:translate="" tal:condition="python: not len(context.keys())">
 There no subobjects registered yet.
 </div>
 
-<table i18n:domain="waeup.sirp">
+<table i18n:domain="waeup.kofa">
   <thead>
     <tr>
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/loginpage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/loginpage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/loginpage.pt	(revision 7811)
@@ -1,3 +1,3 @@
-<form i18n:domain="waeup.sirp" method="post">
+<form i18n:domain="waeup.kofa" method="post">
   <table id="login" class="form-table" summary="Table for entering login information">
     <tbody>
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/myrolespage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/myrolespage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/myrolespage.pt	(revision 7811)
@@ -1,5 +1,5 @@
-<h3 i18n:domain="waeup.sirp"
+<h3 i18n:domain="waeup.kofa"
     i18n:translate="">My Portal Roles:</h3>
-<table i18n:domain="waeup.sirp" class="form-table">
+<table i18n:domain="waeup.kofa" class="form-table">
 <tr tal:repeat="role view/getSiteRoles">
     <td>
@@ -9,5 +9,5 @@
 </table>
 
-<h3 i18n:domain="waeup.sirp"
+<h3 i18n:domain="waeup.kofa"
     i18n:translate="">My Local Roles:</h3>
 <table class="form-table">
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/notfound.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/notfound.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/notfound.pt	(revision 7811)
@@ -1,9 +1,9 @@
-<h2 i18n:domain="waeup.sirp" i18n:translate="">
+<h2 i18n:domain="waeup.kofa" i18n:translate="">
   The page you are trying to access is not available.
 </h2>
 
-<div i18n:domain="waeup.sirp">
+<div i18n:domain="waeup.kofa">
   <b i18n:translate="">Please note the following:</b></div>
-<div i18n:domain="waeup.sirp">
+<div i18n:domain="waeup.kofa">
   <ol class="list">
     <li i18n:translate="">
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/searchpage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/searchpage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/searchpage.pt	(revision 7811)
@@ -6,5 +6,5 @@
 </form>
 <br />
-<span  i18n:domain="waeup.sirp" tal:condition="view/hitlist">
+<span  i18n:domain="waeup.kofa" tal:condition="view/hitlist">
     <h3 i18n:translate="">Search Results</h3>
     <table class="display dataTable">
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/showstudentspage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/showstudentspage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/showstudentspage.pt	(revision 7811)
@@ -1,3 +1,3 @@
-<table i18n:domain="waeup.sirp" class="display dataTable">
+<table i18n:domain="waeup.kofa" class="display dataTable">
   <thead>
 	<tr>
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/staffsitelayout.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/staffsitelayout.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/staffsitelayout.pt	(revision 7811)
@@ -1,4 +1,4 @@
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" i18n:domain="waeup.sirp">
+<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" i18n:domain="waeup.kofa">
   <head>
     <title>WAeUP - your way up
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/studentsitelayout.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/studentsitelayout.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/studentsitelayout.pt	(revision 7811)
@@ -1,4 +1,4 @@
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml" i18n:domain="waeup.sirp">
+<html xmlns="http://www.w3.org/1999/xhtml" i18n:domain="waeup.kofa">
   <head>
     <title>WAeUP - your way up
@@ -10,5 +10,5 @@
     <meta name="viewport" content="width=320, initial-scale=1, maximum-scale=1"/>
     <link rel="stylesheet" media="only screen and (max-device-width: 480px)"
-        tal:attributes="href python: view.url(layout.site, '@@/waeup.sirp.browser/mobile.css')"
+        tal:attributes="href python: view.url(layout.site, '@@/waeup.kofa.browser/mobile.css')"
         type="text/css" />
     <link rel="shortcut icon" tal:attributes="href static/favicon.ico" type="image/x-icon" />
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/universityrss20feed.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/universityrss20feed.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/universityrss20feed.pt	(revision 7811)
@@ -1,11 +1,11 @@
 <?xml version="1.0" encoding="UTF-8"?>
-<rss version="2.0" 
-     xmlns:tal="http://xml.zope.org/namespaces/tal" 
+<rss version="2.0"
+     xmlns:tal="http://xml.zope.org/namespaces/tal"
      xmlns:atom="http://www.w3.org/2005/Atom">
   <channel>
     <title>
       <tal:block tal:content="view/title"/>
-      <tal:block 
-	  tal:define="title view/contexttitle" 
+      <tal:block
+	  tal:define="title view/contexttitle"
 	  tal:condition="title"> - <tal:block content="title"/>
       </tal:block>
@@ -16,20 +16,20 @@
 	tal:content="view/description"></description>
     <language
-	tal:condition="view/language" 
+	tal:condition="view/language"
 	tal:content="view/language"></language>
     <pubDate
-	tal:condition="view/date" 
+	tal:condition="view/date"
 	tal:content="view/date"></pubDate>
     <lastBuildDate
-	tal:condition="view/buildDate" 
+	tal:condition="view/buildDate"
 	tal:content="view/buildDate"></lastBuildDate>
     <managingEditor
-	tal:condition="view/editor" 
+	tal:condition="view/editor"
 	tal:content="view/editor"></managingEditor>
     <webMaster
-	tal:condition="view/webmaster" 
+	tal:condition="view/webmaster"
 	tal:content="view/webmaster"></webMaster>
     <atom:link
-	tal:attributes="href string:${view/link}@@feeds/${view/name}" 
+	tal:attributes="href string:${view/link}@@feeds/${view/name}"
 	rel="self" type="application/rss+xml" />
     <item
@@ -40,18 +40,18 @@
 	  tal:content="item/description"></description>
       <guid
-	  tal:content="item/guid" 
+	  tal:content="item/guid"
 	  tal:define="isPermaLink item/isPermaLink|nothing"
 	  tal:attributes="isPermaLink python:isPermaLink and 'true' or 'false'"></guid>
       <link
-	  tal:condition="item/link|nothing" 
+	  tal:condition="item/link|nothing"
 	  tal:content="item/link"></link>
       <author
-	  tal:condition="item/author|nothing" 
+	  tal:condition="item/author|nothing"
 	  tal:content="item/author"></author>
       <category
-	  tal:condition="item/category|nothing" 
+	  tal:condition="item/category|nothing"
 	  tal:content="item/category"></category>
       <pubDate
-	  tal:condition="item/pubDate|nothing" 
+	  tal:condition="item/pubDate|nothing"
 	  tal:content="item/pubDate"></pubDate>
     </item>
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/usereditformpage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/usereditformpage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/usereditformpage.pt	(revision 7811)
@@ -1,4 +1,4 @@
 <form action="." tal:attributes="action request/URL" method="post"
-      i18n:domain="waeup.sirp" enctype="multipart/form-data">
+      i18n:domain="waeup.kofa" enctype="multipart/form-data">
 
   <table class="form-table">
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/userscontainerpage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/userscontainerpage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/templates/userscontainerpage.pt	(revision 7811)
@@ -1,3 +1,3 @@
-<table i18n:domain="waeup.sirp">
+<table i18n:domain="waeup.kofa">
   <thead>
     <tr>
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/tests/test_captcha.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/tests/test_captcha.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/tests/test_captcha.py	(revision 7811)
@@ -21,9 +21,9 @@
 from zope.interface import verify
 from zope.publisher.browser import TestRequest
-from waeup.sirp.testing import FunctionalLayer, FunctionalTestCase
-from waeup.sirp.browser.captcha import (
+from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
+from waeup.kofa.browser.captcha import (
     CaptchaResponse, CaptchaRequest, NullCaptcha, StaticCaptcha, ReCaptcha,
     CaptchaManager)
-from waeup.sirp.browser.interfaces import (
+from waeup.kofa.browser.interfaces import (
     ICaptchaRequest, ICaptchaResponse, ICaptcha, ICaptchaConfig,
     ICaptchaManager)
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/tests/test_doctests.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/tests/test_doctests.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/tests/test_doctests.py	(revision 7811)
@@ -18,5 +18,5 @@
 """Setup doctests for browser module.
 """
-from waeup.sirp.testing import get_doctest_suite
+from waeup.kofa.testing import get_doctest_suite
 
 def test_suite():
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/tests/test_permissions.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/tests/test_permissions.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/tests/test_permissions.py	(revision 7811)
@@ -31,6 +31,6 @@
 from zope.security.interfaces import Unauthorized
 from zope.testbrowser.testing import Browser
-from waeup.sirp.app import University
-from waeup.sirp.testing import (
+from waeup.kofa.app import University
+from waeup.kofa.testing import (
     FunctionalLayer, FunctionalTestCase, get_all_loggers, remove_new_loggers,
     remove_logger)
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/theming.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/theming.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/theming.py	(revision 7811)
@@ -23,11 +23,11 @@
 from zope.interface import Interface
 from zope.schema.interfaces import IVocabularyFactory
-from waeup.sirp.interfaces import SimpleSIRPVocabulary
-from waeup.sirp.browser.interfaces import ITheme
-from waeup.sirp.browser.resources import (
+from waeup.kofa.interfaces import SimpleKOFAVocabulary
+from waeup.kofa.browser.interfaces import ITheme
+from waeup.kofa.browser.resources import (
     waeuptheme_empty, waeup_base_css,
     )
 
-class SIRPThemeBase(grok.GlobalUtility):
+class KOFAThemeBase(grok.GlobalUtility):
     grok.implements(ITheme)
     grok.name('base waeup theme')
@@ -38,5 +38,5 @@
         return [waeup_base_css]
 
-#class SIRPThemeRed1(grok.GlobalUtility):
+#class KOFAThemeRed1(grok.GlobalUtility):
 #    grok.implements(ITheme)
 #    grok.name('red waeup theme')
@@ -47,5 +47,5 @@
 #        return [waeuptheme_red1]
 
-#class SIRPThemeGray1(grok.GlobalUtility):
+#class KOFAThemeGray1(grok.GlobalUtility):
 #    grok.implements(ITheme)
 #    grok.name('gray waeup theme')
@@ -56,5 +56,5 @@
 #        return [waeuptheme_gray1]
 
-class SIRPThemeEmpty(grok.GlobalUtility):
+class KOFAThemeEmpty(grok.GlobalUtility):
     """A theme based on jQuery only.
 
@@ -87,10 +87,10 @@
     and registered under the name
 
-      'waeup.sirp.browser.theming.ThemesVocabulary'
+      'waeup.kofa.browser.theming.ThemesVocabulary'
 
     Interface fields that wish to provide a list of available themes
     can require a 'named vocabulary', i.e. set:
 
-      vocabulary = 'waeup.sirp.browser.theming.ThemesVocabulary'
+      vocabulary = 'waeup.kofa.browser.theming.ThemesVocabulary'
 
     and the vocabulary will deliver themes and their descriptive text
@@ -101,5 +101,5 @@
     """
     grok.implements(IVocabularyFactory)
-    grok.name('waeup.sirp.browser.theming.ThemesVocabulary')
+    grok.name('waeup.kofa.browser.theming.ThemesVocabulary')
 
     def __call__(self, context):
@@ -112,4 +112,4 @@
         terms = [(theme.description, name)
                  for name, theme in get_all_themes()]
-        vocab = SimpleSIRPVocabulary(*terms)
+        vocab = SimpleKOFAVocabulary(*terms)
         return vocab
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/layout.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/layout.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/layout.py	(revision 7811)
@@ -33,10 +33,10 @@
 from zope.interface import Interface
 from zope.site.hooks import getSite
-from waeup.sirp.interfaces import ISIRPObject, IUserAccount
-from waeup.sirp.browser.interfaces import ITheme
-from waeup.sirp.browser.theming import get_all_themes, SIRPThemeBase
-from waeup.sirp.students.interfaces import IStudentNavigation
-from waeup.sirp.applicants.interfaces import IApplicant
-from waeup.sirp.authentication import get_principal_role_manager
+from waeup.kofa.interfaces import IKOFAObject, IUserAccount
+from waeup.kofa.browser.interfaces import ITheme
+from waeup.kofa.browser.theming import get_all_themes, KOFAThemeBase
+from waeup.kofa.students.interfaces import IStudentNavigation
+from waeup.kofa.applicants.interfaces import IApplicant
+from waeup.kofa.authentication import get_principal_role_manager
 
 grok.templatedir('templates')
@@ -56,12 +56,12 @@
 
     def __call__(self, success):
-        action = SIRPAction(self.label, success=success, **self.options)
+        action = KOFAAction(self.label, success=success, **self.options)
         self.actions.append(action)
         return action
 
-class SIRPAction(Action):
+class KOFAAction(Action):
 
     def __init__(self, label, style='', **options):
-        super(SIRPAction, self).__init__(label, **options)
+        super(KOFAAction, self).__init__(label, **options)
         self.style = style
 
@@ -150,10 +150,10 @@
         return True
 
-class SIRPLayout(UtilityView,Layout):
+class KOFALayout(UtilityView,Layout):
     """A megrok.layout.Layout with additional methods.
     """
     grok.baseclass()
 
-class SIRPForm(UtilityView,Form):
+class KOFAForm(UtilityView,Form):
     """A megrok.layout.Form with additional methods.
     """
@@ -161,5 +161,5 @@
 
     def setUpWidgets(self,ignore_request=False):
-        super(SIRPForm,self).setUpWidgets(ignore_request)
+        super(KOFAForm,self).setUpWidgets(ignore_request)
         # Width parameters will be overridden by Bootstrap
         # so we have to set the css class
@@ -171,10 +171,10 @@
             self.widgets['body'].cssClass = 'span9'
 
-class SIRPPage(UtilityView,Page):
+class KOFAPage(UtilityView,Page):
     """A megrok.layout page with additional methods.
     """
     grok.baseclass()
 
-class SIRPDisplayFormPage(UtilityView,DisplayForm):
+class KOFADisplayFormPage(UtilityView,DisplayForm):
     """A megrok.layout.DisplayForm with additional methods.
     """
@@ -182,5 +182,5 @@
     template = default_waeup_display_template
 
-class SIRPEditFormPage(UtilityView,EditForm):
+class KOFAEditFormPage(UtilityView,EditForm):
     """A megrok.layout.EditForm with additional methods.
     """
@@ -189,5 +189,5 @@
 
     def setUpWidgets(self,ignore_request=False):
-        super(SIRPEditFormPage,self).setUpWidgets(ignore_request)
+        super(KOFAEditFormPage,self).setUpWidgets(ignore_request)
         for widget in self.widgets:
             if widget.__class__.__name__ == 'TextWidget':
@@ -207,5 +207,5 @@
             self.widgets['perm_address'].height = 10
 
-class SIRPAddFormPage(UtilityView,AddForm):
+class KOFAAddFormPage(UtilityView,AddForm):
     """A megrok.layout.AddForm with additional methods.
     """
@@ -213,11 +213,11 @@
     template = default_waeup_edit_template
 
-class SiteLayout(SIRPLayout):
+class SiteLayout(KOFALayout):
     """ The general site layout.
     """
-    grok.context(ISIRPObject)
+    grok.context(IKOFAObject)
 
     #: An instance of the default theme to use for the site layout
-    default_theme = SIRPThemeBase()
+    default_theme = KOFAThemeBase()
     stafftemp = grok.PageTemplateFile('templates/staffsitelayout.pt')
     studenttemp = grok.PageTemplateFile('templates/studentsitelayout.pt')
@@ -297,7 +297,7 @@
         hold the internal name of a theme.
 
         A theme in the waeup.sirp sense consists of a list of
         CSS/JavaScript resources defined in the
-        :mod:`waeup.sirp.browser.resources` module.
+        :mod:`waeup.kofa.browser.resources` module.
 
         If the context University object has no such attribute or the
@@ -297,7 +297,7 @@
         hold the internal name of a theme.
 
-        A theme in the waeup.sirp sense consists of a list of
+        A theme in the waeup.kofa sense consists of a list of
         CSS/JavaScript resources defined in the
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/resources.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/resources.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/resources.py	(revision 7811)
@@ -16,5 +16,5 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
 """Special JavaScript and CSS resources provided by waeup.sirp.
 """
 #from hurry import yui
@@ -24,6 +24,6 @@
 
 
-#: All local resources are registered under the name ``waeup_sirp``.
-waeup_sirp = Library('waeup_sirp', 'static')
+#: All local resources are registered under the name ``waeup_kofa``.
+waeup_kofa = Library('waeup_kofa', 'static')
 
 #: A resource that binds a jQueryUI datepicker widget to each
@@ -36,5 +36,5 @@
 #:   require the JavaScript code to be rendered into the page::
 #:
 #:     from waeup.sirp.browser.resources import datepicker
 #:     # ...
 #:     class MyPage(...):
@@ -89,5 +89,5 @@
 #: ``"datepicker-us-year"``
 #:    same but also adds a select field for year
-datepicker = ResourceInclusion(waeup_sirp, 'datepicker.js',
+datepicker = ResourceInclusion(waeup_kofa, 'datepicker.js',
                                depends=[jqueryui])
 
@@ -99,5 +99,5 @@
 #:   require the JavaScript code to be rendered into the page::
 #:
 #:     from waeup.sirp.browser.resources import warning
 #:     # ...
 #:     class MyPage(...):
@@ -115,5 +115,5 @@
 #:        <input type="submit" name="xyz" value="abc">
 #:               onclick="return confirmPost('Are you sure?')"/>
-warning = ResourceInclusion(waeup_sirp, 'warning.js')
+warning = ResourceInclusion(waeup_kofa, 'warning.js')
 
 #: If you have many select boxes in a from which have to be selected at the same
@@ -123,5 +123,5 @@
 #:   require the JavaScript code to be rendered into the page::
 #:
 #:     from waeup.sirp.browser.resources import toggleall
 #:     # ...
 #:     class MyPage(...):
@@ -138,5 +138,5 @@
 #:
 #:    <input type="checkbox" onClick="toggle(this, 'entries')" />
-toggleall = ResourceInclusion(waeup_sirp, 'toggleall.js')
+toggleall = ResourceInclusion(waeup_kofa, 'toggleall.js')
 
 #: A resource that binds Bootstrap tabs to <div> tags with class
@@ -150,5 +150,5 @@
 #:   tab for redirection::
 #:
 #:     from waeup.sirp.browser.resources import tabs
 #:
 #:     class MyPage(...):
@@ -188,5 +188,5 @@
 #: for details.
 #:
-tabs = ResourceInclusion(waeup_sirp, 'bootstrap-tabs-1.4.0.js',
+tabs = ResourceInclusion(waeup_kofa, 'bootstrap-tabs-1.4.0.js',
                           depends=[jquery])
 
@@ -197,10 +197,10 @@
 #: use of datatables you might want to add some specialized CSS like
 #: `datatable_css` below.
-datatables = ResourceInclusion(waeup_sirp, 'jquery.dataTables.js',
+datatables = ResourceInclusion(waeup_kofa, 'jquery.dataTables.js',
                                minified='jquery.dataTables.min.js',
                                depends=[jquery])
 
 #: A stylesheet for datatables
-datatables_css = ResourceInclusion(waeup_sirp, 'datatables.css')
+datatables_css = ResourceInclusion(waeup_kofa, 'datatables.css')
 
 #: A resource that turns HTML tables into sortable, searchable and :
@@ -214,5 +214,5 @@
 #:   require the JavaScript code to be rendered into the page::
 #:
 #:     from waeup.sirp.browser.resources import datatable
 #:     # ...
 #:     class MyPage(...):
@@ -251,23 +251,23 @@
 #: for details.
 #:
-datatable = ResourceInclusion(waeup_sirp, 'datatable.js',
+datatable = ResourceInclusion(waeup_kofa, 'datatable.js',
                               depends=[datatables, datatables_css])
 
 #: Register Twitter's Bootsrap css including dropdown js as a resource.
 bootstrap_min = ResourceInclusion(
-    waeup_sirp, 'bootstrap-1.4.0.css')
+    waeup_kofa, 'bootstrap-1.4.0.css')
 
 dropdown = ResourceInclusion(
-    waeup_sirp, 'bootstrap-dropdown-1.4.0.js',
+    waeup_kofa, 'bootstrap-dropdown-1.4.0.js',
     depends=[jquery])
 
 #: Register basic SIRP CSS (which is based on ``bootstrap.min-1.4.0.css`` 
 #: and ``base`` as a resource.
 waeup_base_css = ResourceInclusion(
-    waeup_sirp, 'waeup-base.css',
+    waeup_kofa, 'waeup-base.css',
     depends=[dropdown,bootstrap_min, base])
 
 #: A basic theme based on jQuery only (crappy yet).
 waeuptheme_empty = ResourceInclusion(
-    waeup_sirp, 'empty.css',
+    waeup_kofa, 'empty.css',
     depends=[humanity])
@@ -16,5 +16,5 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-"""Special JavaScript and CSS resources provided by waeup.sirp.
+"""Special JavaScript and CSS resources provided by waeup.kofa.
 """
 #from hurry import yui
@@ -36,5 +36,5 @@
 #:   require the JavaScript code to be rendered into the page::
 #:
-#:     from waeup.sirp.browser.resources import datepicker
+#:     from waeup.kofa.browser.resources import datepicker
 #:     # ...
 #:     class MyPage(...):
@@ -99,5 +99,5 @@
 #:   require the JavaScript code to be rendered into the page::
 #:
-#:     from waeup.sirp.browser.resources import warning
+#:     from waeup.kofa.browser.resources import warning
 #:     # ...
 #:     class MyPage(...):
@@ -123,5 +123,5 @@
 #:   require the JavaScript code to be rendered into the page::
 #:
-#:     from waeup.sirp.browser.resources import toggleall
+#:     from waeup.kofa.browser.resources import toggleall
 #:     # ...
 #:     class MyPage(...):
@@ -150,5 +150,5 @@
 #:   tab for redirection::
 #:
-#:     from waeup.sirp.browser.resources import tabs
+#:     from waeup.kofa.browser.resources import tabs
 #:
 #:     class MyPage(...):
@@ -214,5 +214,5 @@
 #:   require the JavaScript code to be rendered into the page::
 #:
-#:     from waeup.sirp.browser.resources import datatable
+#:     from waeup.kofa.browser.resources import datatable
 #:     # ...
 #:     class MyPage(...):
@@ -251,23 +251,23 @@
     depends=[jquery])
 
-#: Register basic SIRP CSS (which is based on ``bootstrap.min-1.4.0.css`` 
+#: Register basic KOFA CSS (which is based on ``bootstrap.min-1.4.0.css`` 
 #: and ``base`` as a resource.
 waeup_base_css = ResourceInclusion(
Index: main/waeup.kofa/trunk/src/waeup/kofa/browser/viewlets.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/browser/viewlets.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/browser/viewlets.py	(revision 7811)
@@ -23,21 +23,21 @@
 from zope.location.interfaces import ISite
 from zope.traversing.browser import absoluteURL
-from waeup.sirp.browser.pages import (
+from waeup.kofa.browser.pages import (
     UniversityPage, FacultiesContainerPage, DatacenterPage, FacultyPage,
     DepartmentPage, CoursePage, CertificatePage, CertificateCoursePage,
     UsersContainerPage, UserManageFormPage)
-from waeup.sirp.browser.interfaces import (
+from waeup.kofa.browser.interfaces import (
     IFacultiesContainer, IFaculty, IDepartment, ICourse, ICertificate,
     ICertificateCourse, IBreadcrumbContainer, IUniversity, IUsersContainer)
-from waeup.sirp.interfaces import (
-    ISIRPUtils, ISIRPObject, ISIRPXMLExporter,
-    ISIRPXMLImporter, IDataCenter, IUserAccount)
-from waeup.sirp.browser.layout import SIRPPage, default_primary_nav_template
-from waeup.sirp.utils.helpers import get_user_account
-
-from waeup.sirp.interfaces import MessageFactory as _
+from waeup.kofa.interfaces import (
+    IKOFAUtils, IKOFAObject, IKOFAXMLExporter,
+    IKOFAXMLImporter, IDataCenter, IUserAccount)
+from waeup.kofa.browser.layout import KOFAPage, default_primary_nav_template
+from waeup.kofa.utils.helpers import get_user_account
+
+from waeup.kofa.interfaces import MessageFactory as _
 
 grok.templatedir('templates')
-grok.context(ISIRPObject) # Make ISIRPObject the default context
+grok.context(IKOFAObject) # Make IKOFAObject the default context
 
 class LeftSidebar(grok.ViewletManager):
@@ -85,5 +85,5 @@
     """
     grok.baseclass()
-    grok.context(ISIRPObject)
+    grok.context(IKOFAObject)
     grok.viewletmanager(ActionBar)
     icon = 'actionicon_modify.png' # File must exist in static/
@@ -126,5 +126,5 @@
             # local to the derived class' module. As we often like to
             # get the icons from here
             # (i.e. waeup.sirp.browser/static), we set the directory
             # resource appropiately.
             #
@@ -134,5 +134,5 @@
             # TODO: notes in here should go to general documentation.
             static = queryAdapter(
-                self.request, Interface, name='waeup.sirp.browser')
+                self.request, Interface, name='waeup.kofa.browser')
         return static[self.icon]()
 
@@ -196,5 +196,5 @@
 
 class BreadCrumbs(grok.Viewlet):
-    grok.context(ISIRPObject)
+    grok.context(IKOFAObject)
     grok.viewletmanager(BreadCrumbManager)
     grok.order(1)
@@ -216,10 +216,10 @@
     """
     grok.viewletmanager(LanguageManager)
-    grok.context(ISIRPObject)
+    grok.context(IKOFAObject)
     grok.require('waeup.Public')
     title = u'Languages'
 
     def render(self):
-        preferred_languages = getUtility(ISIRPUtils).PREFERRED_LANGUAGES_DICT
+        preferred_languages = getUtility(IKOFAUtils).PREFERRED_LANGUAGES_DICT
         html = u''
         for key, value in sorted(
@@ -257,5 +257,5 @@
     grok.baseclass()
     grok.viewletmanager(LeftSidebar)
-    grok.context(ISIRPObject)
+    grok.context(IKOFAObject)
     grok.order(5)
     grok.require('waeup.manageUniversity')
@@ -278,5 +278,5 @@
                 # local to the derived class' module. As we often like to
                 # get the icons from here
                 # (i.e. waeup.sirp.browser/static), we set the directory
                 # resource appropiately.
                 #
@@ -286,5 +286,5 @@
                 # TODO: notes in here should go to general documentation.
                 static = queryAdapter(
-                    self.request, Interface, name='waeup.sirp.browser')
+                    self.request, Interface, name='waeup.kofa.browser')
             return static[self.icon]()
         return
@@ -310,5 +310,5 @@
 
 #
-# waeup.sirp.app.University viewlets...
+# waeup.kofa.app.University viewlets...
 #
 class Login(grok.Viewlet):
@@ -316,5 +316,5 @@
     """
     grok.viewletmanager(LeftSidebar)
-    grok.context(ISIRPObject)
+    grok.context(IKOFAObject)
     grok.view(Interface)
     grok.order(2)
@@ -350,5 +350,5 @@
     """
     grok.viewletmanager(LeftSidebar)
-    grok.context(ISIRPObject)
+    grok.context(IKOFAObject)
     grok.view(Interface)
     grok.order(5)
@@ -520,5 +520,5 @@
 class BrowseActionButton(ActionButton):
     grok.baseclass()
-    grok.context(ISIRPObject)
+    grok.context(IKOFAObject)
     grok.template('actionbutton')
     grok.viewletmanager(ActionBar)
@@ -686,5 +686,5 @@
     target_viewname = 'datacenter'
 
 # The SubobjectLister and its viewlets below are not used in SIRP.
 
 class SubobjectLister(grok.ViewletManager):
@@ -126,5 +126,5 @@
             # local to the derived class' module. As we often like to
             # get the icons from here
-            # (i.e. waeup.sirp.browser/static), we set the directory
+            # (i.e. waeup.kofa.browser/static), we set the directory
             # resource appropiately.
             #
@@ -278,5 +278,5 @@
                 # local to the derived class' module. As we often like to
                 # get the icons from here
-                # (i.e. waeup.sirp.browser/static), we set the directory
+                # (i.e. waeup.kofa.browser/static), we set the directory
                 # resource appropiately.
                 #
@@ -686,5 +686,5 @@
     target_viewname = 'datacenter'
 
-# The SubobjectLister and its viewlets below are not used in SIRP.
+# The SubobjectLister and its viewlets below are not used in KOFA.
 
 class SubobjectLister(grok.ViewletManager):
